package ms.warpzone.warppay.dialogs;

import android.app.Dialog;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.Window;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.activeandroid.query.Select;

import org.w3c.dom.Text;

import java.io.IOException;
import java.util.ArrayList;

import ms.warpzone.warppay.MainActivity;
import ms.warpzone.warppay.R;
import ms.warpzone.warppay.data.models.local.Product;
import ms.warpzone.warppay.data.models.rest.RestProduct;
import ms.warpzone.warppay.data.models.rest.RestUser;
import ms.warpzone.warppay.manager.DataManager;
import ms.warpzone.warppay.manager.MainManager;
import ms.warpzone.warppay.manager.UiManager;
import ms.warpzone.warppay.orderList.ListViewAdapter;
import ms.warpzone.warppay.orderList.Order;
import retrofit.Callback;
import retrofit.Response;
import retrofit.Retrofit;

public class BarcodeLearnDialog extends Dialog implements View.OnClickListener, AdapterView.OnItemClickListener {

    public MainActivity c;
    public Dialog d;

    private Button btnBarcodeSubmit, btnBarcodeDelete, btnExit;
    private ListView lstBarcodeProducts;
    private ArrayAdapter productAdapter;
    private TextView txtBarcodeProductName, txtBarcodeProductBarcode;
    private Product act_product;
    private String barcode="";

    public BarcodeLearnDialog() {
        super(MainManager.getInstance().getMainActivity());
        this.c = MainManager.getInstance().getMainActivity();

    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.barcode_learn_dialog);

        this.btnExit = (Button) findViewById(R.id.btnBarcodeExit);
        this.btnBarcodeSubmit = (Button) findViewById(R.id.btnBarcodeSubmit);
        this.btnBarcodeDelete = (Button) findViewById(R.id.btnBarcodeDelete);
        this.btnExit.setOnClickListener(this);
        this.btnBarcodeSubmit.setOnClickListener(this);
        this.btnBarcodeDelete.setOnClickListener(this);
        this.enableButtons(false);

        this.lstBarcodeProducts = (ListView)findViewById(R.id.lstBarcodeProducts);
        this.productAdapter = new ArrayAdapter(MainManager.getInstance().getMainActivity(), android.R.layout.simple_list_item_1, new ArrayList<Product>());
        this.lstBarcodeProducts.setAdapter(this.productAdapter);
        this.productAdapter.addAll(Product.getAllWithoutBarcode());
        this.lstBarcodeProducts.setOnItemClickListener(this);

        this.txtBarcodeProductName = (TextView) findViewById(R.id.txtBarcodeProductName);
        this.txtBarcodeProductBarcode = (TextView)findViewById(R.id.txtBarcodeProductBarcode);

        this.txtBarcodeProductName.setText("");
        this.txtBarcodeProductBarcode.setText("");


    }

    private void enableButtons(boolean enabled) {
        this.btnBarcodeSubmit.setEnabled(enabled);
        this.btnBarcodeDelete.setEnabled(enabled);

    }
    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btnBarcodeSubmit:
                this.barcode = this.txtBarcodeProductBarcode.getText().toString();
                if(this.barcode != "" && this.act_product != null) {
                    this.act_product.setBarcode(this.barcode);
                    this.act_product.save();
                    RestProduct p = RestProduct.fromLocalProduct(this.act_product);
                    MainManager.getInstance().getRestService().saveBarcode(p.getId(),p).enqueue(new Callback<Void>() {
                        @Override
                        public void onResponse(Response<Void> response, Retrofit retrofit) {

                        }

                        @Override
                        public void onFailure(Throwable t) {
                            Log.d("REST", t.getMessage());
                        }
                    });
                    this.productAdapter.remove(this.act_product);
                    this.act_product = null;
                    this.txtBarcodeProductBarcode.setText("");
                    this.txtBarcodeProductName.setText("");
                    this.barcode = "";
                    this.setBarcode("");

                }
                break;
            case R.id.btnBarcodeDelete:
                this.setBarcode("");
                break;
            case R.id.btnBarcodeExit:
                dismiss();
                break;
        }
    }

    @Override
    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
        this.act_product = (Product) this.productAdapter.getItem(i);
        this.txtBarcodeProductName.setText(this.act_product.getName());

    }

    private void setBarcode(String barcode) {
        if(barcode != "") {
            this.barcode = barcode;
            this.txtBarcodeProductBarcode.setText(barcode);
            this.enableButtons(true);
        } else {
            this.txtBarcodeProductBarcode.setText("");
            this.enableButtons(false);
        }
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {

            if (event.getAction() == KeyEvent.ACTION_UP) {
                if (KeyEvent.KEYCODE_ENTER == event.getKeyCode()) {
                    this.setBarcode(this.barcode.trim().replace("\n", "").toString());
                    this.barcode = "";
                } else {
                    this.barcode += (char) event.getUnicodeChar();
                }

            }

        return super.dispatchKeyEvent(event);
    }

}
